import QtQuick 1.0

Item{
    property string icoType
    property string icoName
    property string icoModified

    width:480
    height:90

    Rectangle{
        id:backgroundRect
        width:480
        height:90
        color: "white"

        Image{
            id:folderIcon
            width: 60
            height: 60
            anchors{
                left:parent.left
                leftMargin: 10
                verticalCenter: parent.verticalCenter
            }

            source:renderIcoSource(icoType)

            Image{
                id:imageThumb
                anchors.fill: parent
            }
        }


        Item{
            width: 410
            height: (icoModified == "")? topItem.paintedHeight: topItem.paintedHeight + bottomItem.paintedHeight
            anchors.left:folderIcon.right
            anchors.leftMargin: 10
            anchors.verticalCenter: parent.verticalCenter

            Text{
                id:topItem
                font.pointSize: 25
                text:icoName

                elide: Text.ElideRight
                width: 360
            }

            Text{
                id:bottomItem
                anchors.top:topItem.bottom
                anchors.topMargin: 3
                color:"#c1c1c1"
                font.pointSize: 20
                text:icoModified

                elide: Text.ElideRight
                width: 360

            }
        }

        Rectangle{
            width:480
            height: 1
            anchors.bottom: parent.bottom
            color:"#f1f1f1"
        }

        MouseArea{
            anchors.fill: parent
            onClicked: {
                if(dir){
                    if(page.name == "directoryPage")
                        directoryModel.append({"dir":filename})
                    else
                        searchDirectoryModel.append({"dir":filename})

                    console.log("recorded:"+filename)

                    loadFolder(filename);
                }

                else{
                    downloadingDialog.open();
                    downloadingDialog.dialogMessage = "Downloading<br />"+unWantedData(filename);
                    udm.downloadFile(accessToken,accessTokenSecret,filename)
                }
            }
            onPressed: changeColor();
            onReleased: changeColor();
        }
    }

    function renderIcoSource(icoType)
    {
        switch(icoType)
        {
        case "folder": return "res/folder.png"
        case "folder_user": return "res/folder-meegoapps.png"
        case "folder_photos": return "res/folder-photos.png"
        case "folder_public": return "res/folder-public.png"
        case "word": return "res/dropbox-api-icons/word48.gif"
        case "excel": return "res/dropbox-api-icons/excel48.gif"
        case "powerpoint": return "res/dropbox-api-icons/powerpoint48.gif"
        case "page_white": return "res/dropbox-api-icons/page_white48.gif"
        case "page_white_zip": return "res/dropbox-api-icons/page_white_zip48.gif"
        case "page_white_visualstudio": return "res/dropbox-api-icons/page_white_visualstudio48.gif"
        case "page_white_vector": return "res/dropbox-api-icons/page_white_vector48.gif"
        case "page_white_tux": return "res/dropbox-api-icons/page_white_tux48.gif"
        case "page_white_text": return "res/dropbox-api-icons/page_white_text48.gif"
        case "page_white_ruby": return "res/dropbox-api-icons/page_white_ruby48.gif"
        case "page_white_picture": /*renderThumb(accessToken, accessTokenSecret, filename);*/return "res/dropbox-api-icons/page_white_picture48.gif"
        case "page_white_php": return "res/dropbox-api-icons/page_white_php48.gif"
        case "page_white_paint": return "res/dropbox-api-icons/page_white_paint48.gif"
        case "page_white_h": return "res/dropbox-api-icons/page_white_h48.gif"
        case "page_white_gear": return "res/dropbox-api-icons/page_white_gear48.gif"
        case "page_white_flash": return "res/dropbox-api-icons/page_white_flash48.gif"
        case "page_white_dvd": return "res/dropbox-api-icons/page_white_dvd48.gif"
        case "page_white_cup": return "res/dropbox-api-icons/page_white_cup48.gif"
        case "page_white_csharp": return "res/dropbox-api-icons/page_white_csharp48.gif"
        case "page_white_cplusplus": return "res/dropbox-api-icons/page_white_cplusplus48.gif"
        case "page_white_code": return "res/dropbox-api-icons/page_white_code48.gif"
        case "page_white_c": return "res/dropbox-api-icons/page_white_c48.gif"
        case "page_white_actionscript": return "res/dropbox-api-icons/page_white_actionscript48.gif"
        case "page_white_acrobat": return "res/dropbox-api-icons/page_white_acrobat48.gif"
        case "page_white_package": return "res/dropbox-api-icons/package48.gif"
        case "music": return "res/dropbox-api-icons/music48.gif"
        default :return ""
        }
    }

    function changeColor()
    {
        if(backgroundRect.color == "#ffffff")
            backgroundRect.color = "#e4e4e4";
        else
            backgroundRect.color = "#ffffff";
    }

    function flickColor()
    {
        backgroundRect.color =  "#ffffff";
    }

    function renderThumb(accessToken,accessTokenSecret,filename)
    {
        udm.getThumb(accessToken, accessTokenSecret, filename)
        filename = filename.slice(filename.lastIndexOf("/")+1)
        imageThumb.source  = "/home/user/.drpbox/"+(filename)
    }
}
