import QtQuick 1.0
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "HelperFunctions.js" as HF


Page{
    id:page
    tools: commonTools
    orientationLock: PageOrientation.LockPortrait
    property string name: "directoryPage"

    BottomBar{id:commonTools}

    onStatusChanged: {
        if(status == PageStatus.Activating){
            directoryModel.clear();
            directoryModel.append({"dir":"/"})
            loadFolder('/')
        }

    }

    Component.onCompleted: {
        commonTools.buttonClicked.connect(searchSheet.clicked)
        commonTools.backClicked.connect(backClicked)
        commonTools.refreshDropBox.connect(refreshDropBox)

        //commonToolsT1.buttonClicked.connect(searchSheet.clicked)
        //commonToolsT1.refreshDropBox.connect(refreshDropBox)
    }



    Rectangle {
        anchors.fill: parent
        color:"#ffffff"

        ListView{
            id:directoryView
            width:480
            height:655
            anchors.top: headerImg.bottom
            signal moved

            onMovementStarted: {
                moved()
            }

            model:dropBoxDirModel
            delegate: DirectoryDelegate{
                id:directoryDelegate
                icoName: unWantedData(filename)
                icoType: type
                icoModified: fh.formatDate(modified)+" | "+size

                Component.onCompleted:  directoryView.moved.connect(directoryDelegate.flickColor)
            }
        }

        Text{
            id:noFileIndicator
            anchors.centerIn: parent
            font.pointSize: 50
            color:"grey"
        }

        Image{
            id:headerImg
            anchors.top: parent.top
            source:"res/header.png"
        }
    }



    ListModel{id:dropBoxDirModel}
    UserDataManager{id:udm}
    LoadingScreen{id:loadingScreen}
    SearchSheet{id:searchSheet}
    DownloadingDialog{id:downloadingDialog}

    InfoBanner{
        id:banner
        text:"Please enter the correct email and password"
    }


    function loadFolder(path){
        noFileIndicator.text = ""
        loadingScreen.show = true
        dropBoxDirModel.clear();
        udm.getFolderContent(accessToken,accessTokenSecret,path,page.setContentPath)
    }

    function setContentPath(data){

        for(var i = 0; i< data.contents.length; i++)
        {
            dropBoxDirModel.append({"filename":data.contents[i].path,"type":data.contents[i].icon,"dir":data.contents[i].is_dir,"modified":data.contents[i].modified,"size":data.contents[i].size})
        }

        if(dropBoxDirModel.count == 0)
            noFileIndicator.text = "No Files Here"
        loadingScreen.show = false;
    }

    function returnResult(data){
        searchString = data
        appState.findPage(searchResultPage,"searchResultPage")
    }

    function unWantedData(data){
        var index = data.lastIndexOf('/')

        data = data.slice(index)
        return data.replace('/',"")
    }

    function backClicked()
    {
        if(directoryModel.count > 1)
        {
            directoryModel.remove(directoryModel.count-1);
            loadFolder(directoryModel.get(directoryModel.count-1).dir)
            return true;
        }
        else
            return false;
    }

    function refreshDropBox()
    {
        dropBoxDirModel.clear();
        loadFolder(directoryModel.get(directoryModel.count-1).dir)
    }
}
