import QtQuick 1.0
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import "HelperFunctions.js" as HF


Page{
    id:page
    tools: BottomBar{id:commonTools}
    orientationLock: PageOrientation.LockPortrait
    property string name: "searchResultPage"

    onStatusChanged: {
        if(status == PageStatus.Activating){
            returnResult(searchString)
            searchDirectoryModel.clear();
            searchDirectoryModel.append({"dir":"/"})
            console.log(searchDirectoryModel.count)
        }
    }

    Component.onCompleted: {
        console.log("completed")
        commonTools.buttonClicked.connect(searchSheet.clicked)
        commonTools.backClicked.connect(backClicked)
    }


    Rectangle {
        anchors.fill: parent
        color:"#ffffff"

        ListView{
            id:directoryView
            width:480
            height:655
            anchors.top: headerImg.bottom
            signal moved

            onMovementStarted: {
                moved()
            }

            model:dropBoxDirModel
            delegate: DirectoryDelegate{
                id:directoryDelegate
                icoName: unWantedData(filename)
                icoType: type
                icoModified: fh.formatDate(modified)+" | "+size

                Component.onCompleted:  directoryView.moved.connect(directoryDelegate.flickColor)
            }
        }

        Text{
            id:noFileIndicator
            anchors.centerIn: parent
            font.pointSize: 50
            color:"grey"
        }

        Image{
            id:headerImg
            anchors.top: parent.top
            source:"res/header.png"
        }
    }

    ListModel{id:dropBoxDirModel}
    UserDataManager{id:udm}
    LoadingScreen{id:loadingScreen}
    SearchSheet{id:searchSheet}
    DownloadingDialog{id:downloadingDialog}
    InfoBanner{
        id:banner
        text:"Please enter the correct email and password"
    }

    function loadFolder(path){
        noFileIndicator.text = ""
        loadingScreen.show = true
        dropBoxDirModel.clear();
        udm.getFolderContent(accessToken,accessTokenSecret,path,page.setContentPath)
    }

    function downloadFile(path){
        var req = udm.downloadFile(accessToken,accessTokenSecret,path)
        var dir = ''
    }

    function setContentPath(data){
        for(var i = 0; i< data.contents.length; i++)
        {
            dropBoxDirModel.append({"filename":data.contents[i].path,"type":data.contents[i].icon,"dir":data.contents[i].is_dir,"modified":data.contents[i].modified,"size":data.contents[i].size})
        }
        noFileIndicator.text = "No Files Here"
        loadingScreen.show = false;
    }

    function returnResult(data){
        dropBoxDirModel.clear();
        noFileIndicator.text = ""
        for(var i = 0; i< data.result.length; i++)
        {
            dropBoxDirModel.append({"filename":data.result[i].path,"type":data.result[i].icon,"dir":data.result[i].is_dir,"modified":data.result[i].modified,"size":data.result[i].size})
        }

        if(dropBoxDirModel.count == 0)
            noFileIndicator.text = "No Match Files"
        loadingScreen.show = false;
    }

    function unWantedData(data){
        var index = data.lastIndexOf('/')
        data = data.slice(index)
        return data.replace('/',"")
    }

    function backClicked()
    {
        if(searchDirectoryModel.count == 2)
        {
            searchDirectoryModel.remove(searchDirectoryModel.count-1)
            returnResult(searchString)
            return true

        }
        else if(searchDirectoryModel.count > 2)
        {
            searchDirectoryModel.remove(searchDirectoryModel.count-1)
            loadFolder(searchDirectoryModel.get(searchDirectoryModel.count-1).dir)
            return true
        }
        else
            return false;


    }

}
