import QtQuick 1.0
import com.nokia.meego 1.0


Page{
    id:page
    tools: BottomBarTypeOne{id:commonTools}
    orientationLock: PageOrientation.LockPortrait
    property string name: "settingPage"

    onStatusChanged: {
        if(status == PageStatus.Activating)
        {
            refreshDropBox();
        }
    }

    Component.onCompleted: {
        commonTools.refreshDropBox.connect(refreshDropBox)
    }

    Rectangle{
        anchors.fill: parent
        color:"#ffffff"

        Rectangle{
            id:subHeader
            color:"#0064a2"
            width: 480
            height:30
            anchors.top: headerImg.bottom

            Text{
                anchors.verticalCenter: parent.verticalCenter
                anchors.left:parent.left
                anchors.leftMargin: 10
                font.pointSize: 15
                color:"white"
                font.bold: true
                text:"Dropbox Account"
            }
        }

        SettingDelegate{
            id:emailDelegate
            anchors.top:subHeader.bottom
            name: "Email"
            value: ""
        }

        SettingDelegate{
            id:spaceDelegate
            anchors.top:emailDelegate.bottom
            name: "Space used"
            value: ""

        }

        SettingDelegate{
            id:unlinkDelegate
            anchors.top:spaceDelegate.bottom
            name: "Unlink device"
            value: ""

            MouseArea{
                anchors.fill: parent
                onReleased: unlinkDelegate.changeColor();
                onPressed: unlinkDelegate.changeColor();
                onClicked: {//disconnect
                    db.deleteUserInfo();
                    accessToken =""
                    accessTokenSecret =""
                    requestToken =""
                    requestTokenSecret = ""
                    appState.findPage(mainPage,"mainPage")
                }
            }
        }

        Rectangle{
            id:abtHeader
            color:"#0064a2"
            width: 480
            height:30
            anchors.top: unlinkDelegate.bottom

            Text{
                anchors.verticalCenter: parent.verticalCenter
                anchors.left:parent.left
                anchors.leftMargin: 10
                font.pointSize: 15
                color:"white"
                font.bold: true
                text:"About"
            }
        }

        SettingDelegate{
            id:abtDelegate
            anchors.top:abtHeader.bottom
            name: "About FileSink"
            value: ""

            MouseArea{
                anchors.fill: parent
                onReleased: abtDelegate.changeColor();
                onPressed: abtDelegate.changeColor();
                onClicked: abtDialog.open();
            }
        }

        SettingDelegate{
            id:reportDelegate
            anchors.top:abtDelegate.bottom
            name: "Report problem"
            value: ""

            MouseArea{
                anchors.fill: parent
                onReleased: reportDelegate.changeColor();
                onPressed: reportDelegate.changeColor();
                onClicked: {Qt.openUrlExternally("mailto:info@nerdattack.com.my")}
            }
        }


        Image{
            id:headerImg
            anchors{
                top:parent.top
            }

            source:"res/header.png"
        }

        QueryDialog{
            id: abtDialog
            icon: "res/dropsinkmeego64.png"
            titleText: "File Sink"
            message: "A DropBox client for Nokia MeeGo devices. If you have any suggestions to help us improve this app, please email them over to info@nerdattack.com.my"
            acceptButtonText: "close"
        }
    }

    UserDataManager{
        id:udm
    }

    LoadingScreen{
        id:loadingScreen
    }

    function setAccountInfo(data){
        if(typeof data["message" === 'undefined']){
            loadingScreen.show = false;
            emailDelegate.value = data.email
            spaceDelegate.value = calcPercent(data.quota_info.normal,data.quota_info.shared,data.quota_info.quota)+" of "+convert(data.quota_info.quota);
        }
    }

    function convert(f) {
        return Math.round(f/1073741824*100000)/100000 + " GB"
    }

    function calcPercent (normal,shared,quota)
    {
        return (Math.round((normal+shared) / quota * 10000))/100 + "%"
    }

    function refreshDropBox(){
        loadingScreen.show = true
        udm.getAccountInfo(accessToken,accessTokenSecret,page.setAccountInfo)
    }

    SearchSheet{id:sheet}
}
