import QtQuick 1.0
import com.nokia.meego 1.0
import drop.sink 1.0

Page{
    id:page
    tools:BottomBarTypeOne{id:commonTools}
    orientationLock: PageOrientation.LockPortrait
    property string name:"uploadPage"

    onStatusChanged: {
        if(status == PageStatus.Activating)
        {
            foldermodel.folder = "/home/user"
            uploadModel.clear();
            uploadModel.append({"dir":foldermodel.folder})
        }
    }

    Component.onCompleted: {
        commonTools.backClicked.connect(backClicked)
        commonTools.refreshDropBox.connect(refreshDropBox)
    }

    Rectangle{
        id:bgRect
        anchors.fill:parent

        Text{
            id:noFileIndicator
            anchors.centerIn: parent
            font.pointSize: 50
            color:"grey"
        }

    }

    ListView {
        id:folderListView
        anchors.top: headerImg.bottom
        anchors.bottom: parent.bottom
        signal moved;


        onMovementStarted: {
            moved();
        }

        onCountChanged: {
            if(count == 0)
                noFileIndicator.text = "No Files Here"
            else
                noFileIndicator.text = ""
        }

        width:480

        model: foldermodel
        delegate: UploadDelegate{
            id:uploadDelegate
            property string filePath: getFileName(foldermodel.folder+"/"+fileName)
            icoName: fileName
            icoType: (foldermodel.isFolder(index))?"folder":""
            icoModified: fh.getModified(filePath)+" | "+bytesToSize(fh.getSize(filePath))

            Component.onCompleted:  folderListView.moved.connect(uploadDelegate.flickColor)
        }

    }

    Image{
        id:headerImg
        source: "res/header.png"
        anchors.top: parent.top
    }

    SelectionDialog{
        id:selectionDialog
        titleText: "Options"
        property string filePath: ""
        model:ListModel{
            ListElement{name:"Upload"}
            ListElement{name:"View"}
            ListElement{name:"Delete"}
        }

        onAccepted: {
            if(selectedIndex  == 0)
            {
                var file = fh.handleFile
                udm.uploadFile(accessToken, accessTokenSecret, filePath, file)
                filePath = filePath.slice(filePath.lastIndexOf('/')+1,filePath.length)
                uploadDialog.open();
                uploadDialog.dialogMessage = filePath

            }

            else if (selectedIndex == 1)
                Qt.openUrlExternally(filePath)

            else if(selectedIndex == 2)
            {
                fh.deleteFile(filePath)
                foldermodel.refresh();
                var path = uploadModel.get(uploadModel.count-1).dir

                path = path.slice(0,path.lastIndexOf("/")+1)
                foldermodel.folder = foldermodel.folder
            }
        }
    }


    UserDataManager{ id:udm}
    UploadingDialog{id:uploadDialog}
    FolderListModel {
        id: foldermodel
    }


    function backClicked()
    {
        if(uploadModel.count > 1)
        {
            uploadModel.remove(uploadModel.count-1);
            foldermodel.folder = uploadModel.get(uploadModel.count-1).dir
            return true;
        }
        else
            return false;
    }

    function getFileName(myString)
    {
        return myString.replace("file://","")
    }

    function bytesToSize(bytes) {
        var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
        if (bytes == 0) return '0 Byte';
        var i = parseInt(Math.floor(Math.log(bytes) / Math.log(1024)));
        return Math.round(bytes / Math.pow(1024, i), 2) + ' ' + sizes[i];
    }

    function refreshDropBox()
    {
        foldermodel.refresh();
    }
}
