import QtQuick 1.0
import com.nokia.meego 1.0
import "HelperFunctions.js" as HF
import "sha1.js" as SHA1
import drop.sink 1.0

Item{
    property string accessType : "dropbox";
    property string root : "dropbox";


    function getAccountInfo(accessToken, accessTokenSecret,callback)
    {

        if(HF.isDefined(accessToken)){
            var req  = dropAuth.getOAuthRequest("GET","https://api.dropbox.com/0/account/info",null,{"token":accessToken, "secret":accessTokenSecret});
            req.onreadystatechange = function(){
                if(req.readyState == XMLHttpRequest.DONE){
                    if(HF.isDefined(req.responseText)&& req.responseText !== ""){
                        var responseData = JSON.parse(req.responseText);
                        if(HF.isDefined(callback)){
                            callback(responseData);
                        }
                    }
                    else if (req.status == 401){
                        unlink()
                        banner.text = "Login Again"
                        banner.show();

                    }
                }
            }

            req.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            req.send();
        }
    }


    function getMetaData(accessToken, accessTokenSecret, path, hash, callback)
    {
        if(HF.isDefined(accessToken)){
            var req = dropAuth.getOAuthRequest("GET","https://api.dropbox.com/0/metadata/"+accessType+HF.percentEncodeURI(path),((hash != null)?[["hash",hash]]:undefined),{"token":accessToken, "secret":accessTokenSecret},[["list","false"]])
            req.setRequestHeader("Host","http://api.dropbox.com")
            req.onreadystatechange = function(){
                if(req.readyState == 4)
                {
                    console.log ("done")
                    console.log(responseText.length)
                    if(HF.isDefined(req.responseText) && req.responseText != "")
                    {
                        var responseData = JSON.parse(req.responseText);
                        console.log(responseData)
                        if(HF.isDefined(callback)){
                            callback(responseData);
                        }
                    }

                    else if (req.status == 401){
                        unlink()
                        banner.text = "Login Again"
                        banner.show();
                    }
                }
            }
            req.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            req.send();
        }
    }

    function getFolderContent(accessToken,accessTokenSecret,path,callback)
    {
        if(HF.isDefined(accessToken)){
            var req = dropAuth.getOAuthRequest("GET", "http://api.dropbox.com/0/metadata/"+accessType+HF.percentEncodeURI(path),null,{"token":accessToken, "secret":accessTokenSecret},[["list","true"]])
            req.setRequestHeader("Host","http://api.dropbox.com");
            req.onreadystatechange = function(){
                if(req.readyState == 4){
                    if(HF.isDefined(req.responseText) && req.responseText != "")
                    {
                        var responseData = JSON.parse(req.responseText);

                        if(HF.isDefined(callback)){
                            callback(responseData);
                        }
                    }
                    else if (req.status == 401){
                        unlink()
                        banner.text = "Login Again"
                        banner.show();
                    }
                }
            }
            req.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            req.send();
        }
    }

    function getThumb(accessToken,accessTokenSecret,path)
    {

        if(HF.isDefined(accessToken)){
            var req = dropAuth.getOAuthRequest("GET", "http://api-content.dropbox.com/0/thumbnails/"+accessType+HF.percentEncodeURI(path),null,{"token":accessToken, "secret":accessTokenSecret},[["size","medium"]])
            req.setRequestHeader("Host","http://api.dropbox.com");
            req.onreadystatechange = function(){
                if(req.readyState == 4){

                    if(req.responseText.length > 0)
                    {
                        path = path.slice(path.lastIndexOf("/")+1)
                        fh.saveThumb(req.responseText,path)
                    }

                    else if (req.status == 401){
                        unlink()
                        banner.text = "Login Again"
                        banner.show();
                    }

                }
            }
            req.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            req.send();
        }

    }

    function downloadFile(accessToken,accessTokenSecret,path)
    {
        var url ="http://api-content.dropbox.com/0/files/"+accessType+path;
        cppOAuth.downloadFile(url,accessToken,accessTokenSecret,dropAuth.appKey,dropAuth.appSecret)
    }

    function uploadFile(accessToken, accessTokenSecret,path,file)
    {
        var url = "https://api-content.dropbox.com/1/files_put/"+accessType+"/Filesink/"+path;
        cppOAuth.handleFile(url,accessToken,accessTokenSecret,dropAuth.appKey,dropAuth.appSecret,path)
    }

    function searchFile(accessToken, accessTokenSecret,query, callback)
    {
        if(HF.isDefined(accessToken)){
            var req = dropAuth.getOAuthRequest("POST", "http://api.dropbox.com/0/search/"+accessType+HF.percentEncodeURI("/"),null,{"token":accessToken, "secret":accessTokenSecret},[["query",query]])
            req.onreadystatechange = function(){
                if(req.readyState == XMLHttpRequest.DONE){
                    loadingScreen.show = false;
                    if(HF.isDefined(req.responseText)&& req.responseText !== ""){
                        var tempResData = '{"result":'+req.responseText+"}"
                        var responseData = JSON.parse(tempResData);

                        if(HF.isDefined(callback)){
                            callback(responseData);
                        }
                    }

                    else if (req.status == 401){
                        unlink()
                        banner.text = "Login Again"
                        banner.show();
                    }

                }
            }

            req.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
            req.send();
        }
    }

    function unlink()
    {
        db.deleteUserInfo();
        accessToken =""
        accessTokenSecret =""
        requestToken =""
        requestTokenSecret = ""
        appState.findPage(mainPage,"mainPage")
    }

    DropBoxAuth{id:dropAuth}

    OAuth{
        id:cppOAuth

        onUploadSuccess: {
            doneDialog.textforTitle = "File Uploaded";
            doneDialog.textforMsg = "File Uploaded to FileSink Folder in your Dropbox"
            uploadDialog.close();
            doneDialog.open();

        }

        onDownloadSuccess:{
            doneDialog.textforTitle = "File Downloaded";
            doneDialog.textforMsg = "File Saved to /home/user/Dropbox"
            downloadingDialog.close();
            doneDialog.open();
        }
    }

    QueryDialog {
        id:doneDialog
        property string textforTitle:"";
        property string textforMsg:"";
        acceptButtonText: "View File"
        rejectButtonText: "Continue"
        icon:"res/tick.png"
        titleText: textforTitle
        message: textforMsg

        onAccepted: {
            if(textforTitle == "File Downloaded")
                appState.findPage(uploadPage,"uploadPage")
            else
                appState.findPage(directoryPage, "directoryPage")
        }
    }
}
